Package: mspms
Type: Package
Title: Tools for the analysis of MSP-MS data
Version: 1.4.0
Authors@R: person("Charlie", "Bayne", email = "baynec2@gmail.com",
    role = c("aut", "cre"),comment=c(ORCID="0000-0003-1870-5298"))
Description: This package provides functions for the analysis of data generated 
    by the multiplex substrate profiling by mass spectrometry for proteases 
    (MSP-MS) method. Data exported from upstream proteomics software is accepted 
    as input and subsequently processed for analysis. 
    Tools for statistical analysis, visualization, and interpretation of 
    the data are provided. 
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.4.0)
biocViews: Proteomics, MassSpectrometry, Preprocessing
LazyData: true
Imports: QFeatures, limma, SummarizedExperiment, magrittr, rlang,
        dplyr, purrr, stats, tidyr, stringr, ggplot2, ggseqlogo,
        heatmaply, readr, rstatix, tibble, ggpubr, imputeLCMD
Suggests: knitr, testthat (>= 3.0.0), downloadthis, DT, rmarkdown,
        BiocStyle
Config/testthat/edition: 3
URL: https://github.com/baynec2/mspms
BugReports: https://github.com/baynec2/mspms/issues
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/mspms
git_branch: RELEASE_3_23
git_last_commit: e8f7cf2
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:28:15 UTC; biocbuild
Author: Charlie Bayne [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1870-5298>)
Maintainer: Charlie Bayne <baynec2@gmail.com>
