% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/preprocessing_helper_functions.R
\name{cterm_cleavage}
\alias{cterm_cleavage}
\title{C-terminal cleavage sequence extraction}
\usage{
cterm_cleavage(...)
}
\value{
A tibble with columns:
  - `peptide`: the input peptide sequence
  - `cterm`: the C-terminal cleavage sequence (n residues on each side)
  - `cterm_cleavage_pos`: the position of the C-terminal cleavage in the library sequence
}
\description{
Wrapper for `cleavage()` that extracts the C-terminal cleavage sequence
and cleavage position from a peptide relative to its library sequence.
}
\keyword{internal}
